# eric7.Project.ProjectVenvCreationParametersDialog

Module implementing a dialog to enter the parameters for the creation of the embedded virtual environment.

### Global Attributes

None

### Classes

ProjectVenvCreationParametersDialog | Class implementing a dialog to enter the parameters for the creation of the embedded virtual environment.

### Functions

None

## ProjectVenvCreationParametersDialog

Class implementing a dialog to enter the parameters for the creation of the embedded virtual environment.

### Derived from

QDialog, Ui_ProjectVenvCreationParametersDialog

### Class Attributes

None

### Class Methods

None

### Methods

ProjectVenvCreationParametersDialog | Constructor
getData | Public method to retrieve the entered data.

### Static Methods

None

#### ProjectVenvCreationParametersDialog (Constructor)

ProjectVenvCreationParametersDialog(withSystemSitePackages=False, parent=None)

Constructor

withSystemSitePackages (bool)
  flag indicating to access the system site-packages (defaults to False)
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### ProjectVenvCreationParametersDialog.getData

getData()

Public method to retrieve the entered data.

Return:
  tuple containing the path of the Python executable and a flag indicating to enable access to the system wide site-packages

Return Type:
  tuple of (str, bool)

Up